@@ -8,8 +8,8 @@
 #ifndef GRADIENTWIDGET_IMPL_H
 #define GRADIENTWIDGET_IMPL_H
 
-#include <QWidget>
 #include "ui_gradientwidget.h"
+#include <QWidget>
 
 #include "kalziumelementproperty.h"
 
@@ -33,7 +33,7 @@ public:
      * @param parent The parent of this widget
      */
     explicit GradientWidgetImpl(QWidget *parent = nullptr);
-    virtual ~GradientWidgetImpl();
+    ~GradientWidgetImpl() override;
 
 Q_SIGNALS:
     /**
@@ -49,9 +49,9 @@ public Q_SLOTS:
     void slotGradientChanged();
 
 private Q_SLOTS:
-    void play(void);
-    void stop(void);
-    void tick(void);
+    void play();
+    void stop();
+    void tick();
     void doubleToSlider(double var);
     void intToSpinbox(int var);
     /**
@@ -60,7 +60,7 @@ private Q_SLOTS:
     void setNewValue(double newValue);
 
 private:
-    bool m_play;        //Indicates whether mode is play or stop
-    QTimer *m_timer;
+    bool m_play = false; // Indicates whether mode is play or stop
+    QTimer *const m_timer;
 };
 #endif // GRADIENTWIDGET_IMPL_H
